<?php
// Allow requests from other domains (CORS policy)
header("Access-Control-Allow-Origin: *");
header("Access-Control-Allow-Methods: POST");
header("Access-Control-Allow-Headers: Content-Type");

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Read the incoming JSON payload
    $input = file_get_contents("php://input");
    $data = json_decode($input, true);

    // Validate required fields
    if (
        isset($data['firstName']) && isset($data['lastName']) &&
        isset($data['phoneNumber']) && isset($data['email']) &&
        isset($data['problemDescription']) && isset($data['message'])
    ) {
        // Sanitize input
        $firstName = htmlspecialchars($data['firstName']);
        $lastName = htmlspecialchars($data['lastName']);
        $phoneNumber = htmlspecialchars($data['phoneNumber']);
        $email = filter_var($data['email'], FILTER_SANITIZE_EMAIL);
        $problemDescription = htmlspecialchars($data['problemDescription']);
        $message = htmlspecialchars($data['message']);

        // Validate email format
        if (!filter_var($email, FILTER_VALIDATE_EMAIL)) {
            echo json_encode([
                "success" => false,
                "message" => "Invalid email format.",
                "response" => "<div style='padding: 20px; background-color: #f2dede; color: #a94442; border-radius: 5px;'>
                    <h2>Error!</h2>
                    <p>Please provide a valid email address.</p>
                </div>"
            ]);
            exit;
        }

        $to = "girdharidusad30@gmail.com"; 
        $subject = "Repair Request from Gold King Scale Website";
        $emailMessage = "
        A repair request has been submitted. Details are as follows:

        First Name: $firstName
        Last Name: $lastName
        Phone Number: $phoneNumber
        Email: $email
        Problem Description: $problemDescription
        Message: $message
        ";

        // Prepare email headers
        $headers = "From: goldkingscale@goldkingscale.com\r\n";
        $headers .= "Reply-To: $email\r\n";
        $headers .= "Content-Type: text/plain; charset=UTF-8\r\n";

        // Send the email
        if (mail($to, $subject, $emailMessage, $headers)) {
            echo json_encode([
                "success" => true,
                "message" => "Email sent successfully.",
                "response" => "<div style='padding: 20px; background-color: #dff0d8; color: #3c763d; border-radius: 5px;'>
                    <h2>Thank you for your request!</h2>
                    <p>Your repair request has been submitted successfully. We will get back to you soon.</p>
                </div>"
            ]);
        } else {
            echo json_encode([
                "success" => false,
                "message" => "Failed to send the email.",
                "response" => "<div style='padding: 20px; background-color: #f2dede; color: #a94442; border-radius: 5px;'>
                    <h2>Error!</h2>
                    <p>There was an issue submitting your request. Please try again later.</p>
                </div>"
            ]);
        }
    } else {
        echo json_encode([
            "success" => false,
            "message" => "Invalid input data.",
            "response" => "<div style='padding: 20px; background-color: #f2dede; color: #a94442; border-radius: 5px;'>
                <h2>Error!</h2>
                <p>Some required fields are missing. Please fill in all the fields correctly.</p>
            </div>"
        ]);
    }
} else {
    echo json_encode([
        "success" => false,
        "message" => "Invalid request method.",
        "response" => "<div style='padding: 20px; background-color: #f2dede; color: #a94442; border-radius: 5px;'>
            <h2>Error!</h2>
            <p>The request method is not valid. Please send a POST request.</p>
        </div>"
    ]);
}
?>
