<?php
// Enable error reporting for debugging
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

// Set headers for JSON response and CORS
header('Content-Type: application/json; charset=UTF-8');
header('Access-Control-Allow-Origin: *');
header('Access-Control-Allow-Methods: GET');
header('Access-Control-Allow-Headers: Access-Control-Allow-Headers, Content-Type, Access-Control-Allow-Methods, Authorization, X-Requested-With');

// Include database configuration file
include 'config.php';

// Check database connection
if (!$conn) {
    echo json_encode(['error' => 'Database connection failed: ' . mysqli_connect_error()]);
    exit;
}

// Fetch 5 visible categories
$categoryQuery = "SELECT id, name, img, visible FROM category WHERE visible = 1 LIMIT 5";
$categoryResult = mysqli_query($conn, $categoryQuery);

if (!$categoryResult) {
    echo json_encode(['error' => 'Category query failed: ' . mysqli_error($conn)]);
    exit;
}

$categories = [];
while ($category = mysqli_fetch_assoc($categoryResult)) {
    $categories[] = $category;
}

// Fetch products where visible = 1
$productQuery = "SELECT id, Name, Category_id, Price, `Img-1` AS img, visible FROM product WHERE visible = 1";
$productResult = mysqli_query($conn, $productQuery);

if (!$productResult) {
    echo json_encode(['error' => 'Product query failed: ' . mysqli_error($conn)]);
    exit;
}

$products = [];
while ($product = mysqli_fetch_assoc($productResult)) {
    $products[] = $product;
}

// Structure the response by categorizing products under their respective categories
$response = [];
foreach ($categories as $category) {
    $categoryProducts = array_filter($products, function ($product) use ($category) {
        return $product['Category_id'] == $category['id'];
    });

    $response[] = [
        'category' => $category,
        'products' => array_values($categoryProducts)
    ];
}

// Return the response in JSON format
echo json_encode($response, JSON_UNESCAPED_UNICODE | JSON_PRETTY_PRINT);
?>
